@@ -2,13 +2,14 @@
 """
 from mongoengine import errors as mongoengine_errors
 
-from core_explore_common_app.components.abstract_persistent_query.models import AbstractPersistentQuery
+from core_explore_common_app.components.abstract_persistent_query.models import (
+    AbstractPersistentQuery,
+)
 from core_main_app.commons import exceptions
 
 
 class PersistentQueryExample(AbstractPersistentQuery):
-    """ Persistent Query Example
-    """
+    """Persistent Query Example"""
 
     @staticmethod
     def get_by_id(query_id):
